CDOK0
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                    C
C     ***  CNM3DK ***              Last revision:    08-Jul-96       C
C                                                                    C
C     Programme calculates the 2D thin plate coefficients for        C
C     generating normal force and moment coefficients in the         C
C     calling programme (Kuessner's and Theordorsen's analytical     C
C     solution for pitching and plunging motion - published 1936).   C
C                                                                    C
C     Kinematics:                                                    C
C                                                                    C
C                   n                                                C
C              1. v     =  1.            ( reference  a * u0  )      C
C                  kin                                               C
C                                                                    C
C                 The respective values for the time derivative      C
C                 are obtained by multipling with i*OMS              C
C                                                                    C
C                   n                                 a * u0         C
C                 v     =  i*OMS         ( reference  ------  )      C
C                  kin                                 L/2           C
C                                                                    C
C                   n                                                C
C              2. v     =  2i*OMS(xsi-1/4)   (reference  a*u0 )      C
C                  kin                                               C
C                                                                    C
C              a is a dimensionless amplitude (e.g. an angle).       C
C              If a is a spacial coordinate, it has to made          C
C              dimensionless by dividing by L/2 (see below).         C
C                                                                    C
C                                                   OMEGA * L/2      C
C     Input: : Reduced frequency        OMS     :=  ----------       C
C                                                      U0            C
C              -  Circular frequency  OMEGA                          C
C              -  Onset velocity      U0                             C
C              -  Chord length        L                              C
C                                                                    C
C              Relative pitch axis      XDR        referred to L     C
C              moment axis, respectively                             C
C                                                                    C
C     Output:  Lift coefficient         CN#        # : eta or        C
C              Moment coefficient       CM#            xsi           C
C                                                                    C
C              Values referred to 2*pi                               C
C                                                                    C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CEDOK

      SUBROUTINE CNM3DK (OMS,XDR,CNeta,CMeta,CNxsi,CMxsi)
      IMPLICIT   COMPLEX*16(C),REAL*8(D-H,O-Z)
      DIMENSION  ch2(0:1)
      SAVE       OMS0,CTH
      DATA       OMS0,CTH / 0d0,(1d0,0d0) /
      EXTERNAL   DBSJ0,DBSJ1,DBSY0,DBSY1

C ... Theodorsen funktion
      if (OMS .ne. OMS0) then
C ...     Theodorsen funktion CTHEO
C         DBSJn  : Besselfunction 1. kind, nth order   ) IMSL
C         DBSYn  : Besselfunction 2. kind, nth order   ) Library
C         CH2(n) : Hankelfunctions  2. kind, nth order )
C
          CH2(0) = CMPLX(DBSJ0(OMS),-DBSY0(OMS))
          CH2(1) = CMPLX(DBSJ1(OMS),-DBSY1(OMS))
          CTH  = CH2(1)/(CH2(1)+(0,1)*CH2(0))
C xxx     CTH  = CTHEOD(OMS)
          OMS0 = OMS
      end if


C *** Values for quarter chord
      OMSS    = OMS*OMS
      CIOMS   = cmplx(0D0,OMS)

C ... 1. "Plunge" (eta)
      CNeta     = CTH+5D-1*CIOMS
      CMeta     = -0.125D0*CIOMS
C ... 2. "Pitch" (xsi)
      CNxsi   = CIOMS*(CTH+0.25D0*CIOMS)
      CMxsi   = -CIOMS*dcmplx(1D0,0.75D0*OMS)/8D0
      IF (XDR .EQ. 0.25D0) GOTO 100

C *** Values for chord unequal quarter chord
      CMetaL4 = CMeta
      CNxsiL4 = CNxsi
      CMxsiL4 = CMxsi
      xsiP    = XDR-0.25D0
      C2IOMS  = cmplx(0D0,OMS+OMS)
      CMeta   = CMetaL4+xsiP*CNeta
C     Factor 2 preceding eta parts is missing due to external 2i*oms
      CNxsi   = CNxsiL4-C2IOMS*xsiP*CNeta
      CMxsi   = CMxsiL4+xsiP*CNxsiL4-C2IOMS*(xsiP*CMetaL4+
     *                                   xsiP*xsiP*CNeta)

  100 RETURN
      END
